#' Create maps of shipboard DAS data
#'
#' A utility program oriented to create maps, plot data, and do basic data summaries
#' from data files in the "DAS" format, typically produced by WinCruz.
#'
#' @name CruzPlot-package
#' @aliases cruzplot CruzPlot
#' @title CruzPlot
#' @author Sam Woodman \email{sam.woodman@@noaa.gov}
#' @seealso \url{https://swfsc.github.io/CruzPlot/}
#'
#' @importFrom shiny runApp
#'
"_PACKAGE"
